[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Getfem-commits] r4738 - in /trunk/getfem: doc/sphinx/source/userdoc/ in
From: |
Yves . Renard |
Subject: |
[Getfem-commits] r4738 - in /trunk/getfem: doc/sphinx/source/userdoc/ interface/src/ src/getfem/ |
Date: |
Sun, 27 Jul 2014 12:25:55 -0000 |
Author: renard
Date: Sun Jul 27 14:25:54 2014
New Revision: 4738
URL: http://svn.gna.org/viewcvs/getfem?rev=4738&view=rev
Log:
minor fixes
Modified:
trunk/getfem/doc/sphinx/source/userdoc/gasm_high.rst
trunk/getfem/doc/sphinx/source/userdoc/install.rst
trunk/getfem/doc/sphinx/source/userdoc/model_object.rst
trunk/getfem/interface/src/gf_mesh_get.cc
trunk/getfem/src/getfem/getfem_model_solvers.h
trunk/getfem/src/getfem/getfem_modeling.h
Modified: trunk/getfem/doc/sphinx/source/userdoc/gasm_high.rst
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/doc/sphinx/source/userdoc/gasm_high.rst?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================
--- trunk/getfem/doc/sphinx/source/userdoc/gasm_high.rst (original)
+++ trunk/getfem/doc/sphinx/source/userdoc/gasm_high.rst Sun Jul 27
14:25:54 2014
@@ -582,7 +582,7 @@
where ``alpha`` should be a valid declared variable or data.
-The macros are expanded inline at the semantic analysis phase. At the
compilation phase, if severla call of the same macro is performed, the
computation is automatically factorized.
+The macros are expanded inline at the semantic analysis phase. At the
compilation phase, if several call of the same macro is performed, the
computation is automatically factorized.
Interpolate transformations
***************************
Modified: trunk/getfem/doc/sphinx/source/userdoc/install.rst
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/doc/sphinx/source/userdoc/install.rst?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================
--- trunk/getfem/doc/sphinx/source/userdoc/install.rst (original)
+++ trunk/getfem/doc/sphinx/source/userdoc/install.rst Sun Jul 27 14:25:54 2014
@@ -42,20 +42,20 @@
There are two ways to get |gf|, either as a compressed package (stable
release) or via anonymous svn access (unstable releases).
-The latest stable release of |gf| is `getfem-4.0.0.tar.gz
-<http://download.gna.org/getfem/stable/getfem-4.0.0.tar.gz>`_.
+The latest stable release of |gf| is `getfem-4.3.tar.gz
+<http://download.gna.org/getfem/stable/getfem-4.3.tar.gz>`_.
* download package::
- $ wget http://download.gna.org/getfem/stable/getfem-4.0.0.tar.gz
+ $ wget http://download.gna.org/getfem/stable/getfem-4.3.tar.gz
* unpack::
- $ tar xzf getfem-4.0.0.tar.gz
+ $ tar xzf getfem-4.3.tar.gz
* and go to the root directory of |gf|::
- $ cd getfem-4.0.0/
+ $ cd getfem-4.3/
The latest unstable releases is:
Modified: trunk/getfem/doc/sphinx/source/userdoc/model_object.rst
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/doc/sphinx/source/userdoc/model_object.rst?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================
--- trunk/getfem/doc/sphinx/source/userdoc/model_object.rst (original)
+++ trunk/getfem/doc/sphinx/source/userdoc/model_object.rst Sun Jul 27
14:25:54 2014
@@ -154,7 +154,7 @@
The |br| object
---------------
-A model brick is an object which is supposed to represent a part of a model. It
+A model brick is an object that is supposed to represent a part of a model. It
aims to represent some integral terms in a weak formulation of a PDE model. The
model object will contain a list of bricks. All the terms described by the
brick
will be finally assembled to build the linear system to be solved (the tangent
@@ -178,6 +178,11 @@
How to build a new brick
------------------------
+
+Note first that the design of a new brick is only necessary for special terms
+not covered by existing bricks and not covered by the wide range of accessible
+terms (including complex coupling terms) of the generic assembly brick
+(see :ref:`ud-model-generic-assembly`).
According to the spirit in which the brick has been designed, a brick should
avoid
as much as possible to store additional data. The parameters of a brick should
be
Modified: trunk/getfem/interface/src/gf_mesh_get.cc
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/interface/src/gf_mesh_get.cc?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================
--- trunk/getfem/interface/src/gf_mesh_get.cc (original)
+++ trunk/getfem/interface/src/gf_mesh_get.cc Sun Jul 27 14:25:54 2014
@@ -123,7 +123,7 @@
iarray w = out.pop().create_iarray(2,unsigned(lst.size()));
for (size_type j=0; j < lst.size(); j++) {
w(0,j) = int(lst[j].cv+config::base_index());
- w(1,j) = int(lst[j].f+config::base_index());
+ w(1,j) = int(short_type(lst[j].f+config::base_index()));
}
}
@@ -192,8 +192,8 @@
fcnt = 0;
for (size_type j=0; j < lst.size(); j++) {
if (lst[j].cnt == 1) {
- w(0,fcnt) = int(lst[j].cv)+config::base_index();
- w(1,fcnt) = int(lst[j].f)+config::base_index();
+ w(0,fcnt) = int(lst[j].cv+config::base_index());
+ w(1,fcnt) = int(short_type(lst[j].f+config::base_index()));
fcnt++;
}
}
@@ -928,7 +928,7 @@
iarray w = out.pop().create_iarray(2, unsigned(cvlst.size()));
for (size_type j=0; j < cvlst.size(); j++) {
w(0,j) = cvlst[j]+config::base_index();
- w(1,j) = facelst[j]+config::base_index();
+ w(1,j) = short_type(facelst[j]+config::base_index());
}
);
@@ -963,7 +963,7 @@
iarray w = out.pop().create_iarray(2, unsigned(cvlst.size()));
for (size_type j=0; j < cvlst.size(); j++) {
w(0,j) = cvlst[j]+config::base_index();
- w(1,j) = facelst[j]+config::base_index();
+ w(1,j) = short_type(facelst[j]+config::base_index());
}
);
Modified: trunk/getfem/src/getfem/getfem_model_solvers.h
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/src/getfem/getfem_model_solvers.h?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================
--- trunk/getfem/src/getfem/getfem_modeling.h (original)
+++ trunk/getfem/src/getfem/getfem_modeling.h Sun Jul 27 14:25:54 2014
@@ -40,6 +40,10 @@
//==============================================
//
+// DEPRECATED MODEL DESCRIPTION. Use the new one in getfem_model.h
+//
+//==============================================
+//
// Brick idents :
// MDBRICK_GENERIC_ELLIPTIC 174397
// MDBRICK_LIN_ISO_ELASTICITY 852327
@@ -429,8 +433,8 @@
PARAM_MAP &get_parameters() { return parameters; }
- mdbrick_abstract_common_base(void)
- : proper_additional_dof(0), proper_nb_constraints(0), MS_i0(0) {
+ IS_DEPRECATED mdbrick_abstract_common_base(void)
+ : proper_additional_dof(0), proper_nb_constraints(0), MS_i0(0) {
proper_is_linear_ = proper_is_symmetric_ = proper_is_coercive_ = true;
nb_total_constraints = nb_total_dof = 1000000000L;
proper_additional_dof = proper_nb_constraints = 0;
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [Getfem-commits] r4738 - in /trunk/getfem: doc/sphinx/source/userdoc/ interface/src/ src/getfem/,
Yves . Renard <=
--- trunk/getfem/src/getfem/getfem_model_solvers.h (original)
+++ trunk/getfem/src/getfem/getfem_model_solvers.h Sun Jul 27 14:25:54 2014
@@ -1064,7 +1064,7 @@
/* Standard solve. */
/* ***************************************************************** */
/** A default solver for the old model brick system.
Of course it could be not very well suited for a particular
problem, so it could be copied and adapted to change solvers,
@@ -1119,11 +1119,19 @@
template <typename MODEL_STATE> void
standard_solve(MODEL_STATE &MS, mdbrick_abstract<MODEL_STATE> &problem,
gmm::iteration &iter,
- typename useful_types<MODEL_STATE>::plsolver_type lsolver) {
+ typename useful_types<MODEL_STATE>::plsolver_type lsolver)
IS_DEPRECATED;
+
+ template <typename MODEL_STATE> void
+ standard_solve(MODEL_STATE &MS, mdbrick_abstract<MODEL_STATE> &problem,
+ gmm::iteration &iter,
+ typename useful_types<MODEL_STATE>::plsolver_type lsolver) {
default_newton_line_search ls;
standard_solve(MS, problem, iter, lsolver, ls);
}
+ template <typename MODEL_STATE> void
+ standard_solve(MODEL_STATE &MS, mdbrick_abstract<MODEL_STATE> &problem,
+ gmm::iteration &iter) IS_DEPRECATED;
template <typename MODEL_STATE> void
standard_solve(MODEL_STATE &MS, mdbrick_abstract<MODEL_STATE> &problem,
Modified: trunk/getfem/src/getfem/getfem_modeling.h
@@ -1064,7 +1064,7 @@
/* Standard solve. */
/* ***************************************************************** */
- /** A default solver for the old model brick system.
+ /** A default solver for the old and deprecated model brick system.
Of course it could be not very well suited for a particular
problem, so it could be copied and adapted to change solvers,
URL:
http://svn.gna.org/viewcvs/getfem/trunk/getfem/src/getfem/getfem_modeling.h?rev=4738&r1=4737&r2=4738&view=diff
==============================================================================